// Generated by CoffeeScript 1.3.3
var __slice = [].slice;

define(['underscore', 'serrano/channels', 'serrano/datafield', 'serrano/dataconcept', 'serrano/datacontext', 'serrano/dataview'], function() {
  var modules, _;
  _ = arguments[0], modules = 2 <= arguments.length ? __slice.call(arguments, 1) : [];
  return _.extend.apply(_, [{}].concat(__slice.call(modules)));
});
