// Generated by CoffeeScript 1.3.3
var __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

define(['backbone'], function(Backbone) {
  var DataConcept, DataConcepts;
  DataConcept = (function(_super) {

    __extends(DataConcept, _super);

    function DataConcept() {
      return DataConcept.__super__.constructor.apply(this, arguments);
    }

    return DataConcept;

  })(Backbone.Model);
  DataConcepts = (function(_super) {

    __extends(DataConcepts, _super);

    function DataConcepts() {
      return DataConcepts.__super__.constructor.apply(this, arguments);
    }

    DataConcepts.prototype.model = DataConcept;

    return DataConcepts;

  })(Backbone.Collection);
  return {
    DataConcept: DataConcept,
    DataConcepts: DataConcepts
  };
});
