// Generated by CoffeeScript 1.3.3

define(['highcharts'], function(Highcharts) {
  var defaults, sparkline;
  defaults = {
    chart: {
      style: {
        fontFamily: '"Helvetica Neue", Helvetica, Arial, sans-serif'
      }
    },
    title: {
      text: '',
      align: 'right'
    },
    subtitle: {
      align: 'right'
    },
    exporting: {
      enabled: false
    },
    credits: {
      enabled: false
    },
    tooltip: {
      snap: 1,
      useHTML: true,
      borderWidth: 1,
      borderRadius: 3
    },
    plotOptions: {
      series: {
        shadow: false,
        animation: {
          duration: 400
        }
      },
      area: {
        lineWidth: 1,
        shadow: false,
        stacking: 'normal',
        states: {
          hover: {
            lineWidth: 1
          }
        },
        marker: {
          enabled: false,
          states: {
            hover: {
              enabled: true,
              radius: 5
            }
          }
        },
        fillOpacity: 0.1
      },
      areaspline: {
        lineWidth: 1,
        shadow: false,
        states: {
          hover: {
            lineWidth: 1
          }
        },
        marker: {
          enabled: false,
          states: {
            hover: {
              enabled: true
            }
          }
        },
        fillOpacity: 0.1
      },
      bar: {
        borderWidth: 0,
        minPointLength: 2
      },
      column: {
        borderWidth: 0,
        minPointLength: 2
      },
      pie: {
        allowPointSelect: true,
        cursor: 'pointer',
        showInLegend: true
      },
      scatter: {
        marker: {
          radius: 5,
          states: {
            hover: {
              enabled: false
            }
          }
        },
        states: {
          hover: {
            marker: {
              enabled: false
            }
          }
        }
      }
    }
  };
  sparkline = {
    chart: {
      defaultSeriesType: 'areaspline',
      margin: [0, 0, 0, 0]
    },
    title: {
      text: '',
      align: 'left',
      y: 0,
      x: 0,
      style: {
        fontSize: '8px',
        color: '#333333'
      }
    },
    credits: {
      enabled: false
    },
    legend: {
      enabled: false
    },
    tooltip: {
      enabled: false
    },
    xAxis: {
      startOnTick: true,
      labels: {
        enabled: false
      }
    },
    yAxis: {
      endOnTick: false,
      labels: {
        enabled: false
      }
    },
    plotOptions: {
      series: {
        lineWidth: 1,
        shadow: false,
        states: {
          hover: {
            enabled: false
          }
        },
        marker: {
          enabled: false
        }
      },
      areaspline: {
        fillOpacity: 0.1
      },
      area: {
        fillOpacity: 0.1
      }
    }
  };
  return {
    defaults: defaults,
    sparkline: sparkline
  };
});
