{% load url from future %}

<a class=brand href="{% block brand_url %}{% url "index" %}{% endblock %}">
    {% block brand_title %}{% firstof cilantro.config.title site.name site.domain "Cilantro" %}{% endblock %}
    {% if cilantro.config.label %}
        <span class="label label-info">{{ cilantro.config.label }}</span>
    {% endif %}
</a>
