// Generated by CoffeeScript 1.3.3

define(function() {
  return {
    DATACONTEXT_CHANGED: 'datacontext/changed',
    DATACONTEXT_SYNCING: 'datacontext/syncing',
    DATACONTEXT_SYNCED: 'datacontext/synced',
    DATACONTEXT_PAUSE: 'datacontext/pause',
    DATACONTEXT_RESUME: 'datacontext/resume',
    DATACONTEXT_ADD: 'datacontext/add',
    DATACONTEXT_REMOVE: 'datacontext/remove',
    DATACONTEXT_CLEAR: 'datacontext/clear',
    DATACONTEXT_HISTORY: 'datacontext/history',
    DATAVIEW_CHANGED: 'dataview/changed',
    DATAVIEW_SYNCING: 'dataview/syncing',
    DATAVIEW_SYNCED: 'dataview/synced',
    DATAVIEW_PAUSE: 'dataview/pause',
    DATAVIEW_RESUME: 'dataview/resume',
    DATAVIEW_COLUMNS: 'dataview/columns',
    DATAVIEW_ORDERING: 'dataview/ordering',
    DATAVIEW_HISTORY: 'dataview/history'
  };
});
