var __hasProp={}.hasOwnProperty,__extends=function(e,t){function r(){this.constructor=e}for(var n in t)__hasProp.call(t,n)&&(e[n]=t[n]);return r.prototype=t.prototype,e.prototype=new r,e.__super__=t.prototype,e};define(["environ","mediator","jquery","underscore","backbone","views/containers","serrano"],function(e,t,n,r,i,s,o){var u;return u=function(e){function n(){return n.__super__.constructor.apply(this,arguments)}return __extends(n,e),n.prototype.id="workspace-area",n.prototype.initialize=function(){return this.activity=new s.Container,this.activity.$el.addClass("span6"),this.activity.heading.text("Activity"),this.queries=new s.Container,this.queries.$el.addClass("span6"),this.queries.heading.text("Queries"),this.$el.hide().appendTo("#main-area .inner").addClass("row-fluid").append(this.queries.render(),this.activity.render()),t.subscribe(o.DATACONTEXT_HISTORY,function(e){}),t.subscribe(o.DATAVIEW_HISTORY,function(e){})},n.prototype.load=function(){return this.$el.show()},n.prototype.unload=function(){return this.$el.hide()},n}(i.View)})