define("serrano/channels",[],function(){return{DATACONTEXT_CHANGED:"datacontext/changed",DATACONTEXT_SYNCING:"datacontext/syncing",DATACONTEXT_SYNCED:"datacontext/synced",DATACONTEXT_PAUSE:"datacontext/pause",DATACONTEXT_RESUME:"datacontext/resume",DATACONTEXT_ADD:"datacontext/add",DATACONTEXT_REMOVE:"datacontext/remove",DATACONTEXT_CLEAR:"datacontext/clear",DATACONTEXT_HISTORY:"datacontext/history",DATAVIEW_CHANGED:"dataview/changed",DATAVIEW_SYNCING:"dataview/syncing",DATAVIEW_SYNCED:"dataview/synced",DATAVIEW_PAUSE:"dataview/pause",DATAVIEW_RESUME:"dataview/resume",DATAVIEW_COLUMNS:"dataview/columns",DATAVIEW_ORDERING:"dataview/ordering",DATAVIEW_HISTORY:"dataview/history"}});var __bind=function(e,t){return function(){return e.apply(t,arguments)}},__hasProp={}.hasOwnProperty,__extends=function(e,t){function r(){this.constructor=e}for(var n in t)__hasProp.call(t,n)&&(e[n]=t[n]);return r.prototype=t.prototype,e.prototype=new r,e.__super__=t.prototype,e};define("views/counter",["environ","mediator","jquery","underscore","backbone","serrano/channels"],function(e,t,n,r,i,s){var o;return o=function(e){function n(){return this.render=__bind(this.render,this),n.__super__.constructor.apply(this,arguments)}return __extends(n,e),n.prototype.className="datacontext-count",n.prototype.initialize=function(){var e=this;return this.model&&this.model.id&&(this.model=this.model.id),t.subscribe(s.DATACONTEXT_SYNCING,function(t){if(t.isSession())return e.$el.addClass("loading")}),t.subscribe(s.DATACONTEXT_SYNCED,function(t,n){if(t.isSession())return e.$el.removeClass("loading"),e.render(t)})},n.prototype.render=function(e){var t,n,r,i;return e&&(t=e.get("count"))!=null?(i=App.Numbers.toSuffixedNumber(t),n=App.Numbers.toDelimitedNumber(t),r=t===1?e.get("object_name"):e.get("object_name_plural"),this.$el.html(""+i+" <span class=muted>"+(r||"")+"</span>").attr("title",n),t===0?this.$el.addClass("text-error"):this.$el.removeClass("text-error")):this.$el.html("&infin;"),this.$el},n}(i.View)});var __hasProp={}.hasOwnProperty,__extends=function(e,t){function r(){this.constructor=e}for(var n in t)__hasProp.call(t,n)&&(e[n]=t[n]);return r.prototype=t.prototype,e.prototype=new r,e.__super__=t.prototype,e};define("routes/app",["environ","mediator","jquery","underscore","backbone","views/counter"],function(e,t,n,r,i,s){var o;return o=function(e){function t(){return t.__super__.constructor.apply(this,arguments)}return __extends(t,e),t.prototype.load=function(){var e;return e=new s,this.$toolbar=n("<ul>").addClass("nav pull-left").appendTo("#subnav .container-fluid"),this.$toolbar.append(n("<li>").html(e.render()))},t}(i.View)})