{% load url from future %}

<li class=dropdown>
    <a href=# class=dropdown-toggle data-toggle=dropdown>
        <i class="icon-user icon-white"></i> Account <b class=caret></b>
    </a>
    <ul class=dropdown-menu>
        {% if user.is_staff %}
            <li><a href={% url "admin:index" %}>Admin</a></li>
        {% endif %}
        <li><a href={% url "admin:logout" %}>Logout</a></li>
    </ul>
</li>
