// Generated by CoffeeScript 1.3.3
var __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

define(['backbone'], function(Backbone) {
  var DataField, DataFields;
  DataField = (function(_super) {

    __extends(DataField, _super);

    function DataField() {
      return DataField.__super__.constructor.apply(this, arguments);
    }

    return DataField;

  })(Backbone.Model);
  DataFields = (function(_super) {

    __extends(DataFields, _super);

    function DataFields() {
      return DataFields.__super__.constructor.apply(this, arguments);
    }

    DataFields.prototype.model = DataField;

    return DataFields;

  })(Backbone.Collection);
  return {
    DataField: DataField,
    DataFields: DataFields
  };
});
