var __hasProp={}.hasOwnProperty,__extends=function(e,t){function r(){this.constructor=e}for(var n in t)__hasProp.call(t,n)&&(e[n]=t[n]);return r.prototype=t.prototype,e.prototype=new r,e.__super__=t.prototype,e};define(["environ","jquery","underscore","backbone"],function(e,t,n,r){var i;return i=function(e){function t(){return t.__super__.constructor.apply(this,arguments)}return __extends(t,e),t.prototype.template=n.template("            <div class=area-container>                <h3 class=heading></h3>                <div class=content></div>            </div>        "),t.prototype.initialize=function(){return this.setElement(this.template()),this.heading=this.$el.find(".heading"),this.content=this.$el.find(".content")},t.prototype.render=function(){return this.$el},t}(r.View),{Container:i}})