// Generated by CoffeeScript 1.3.3
var __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

define(['environ', 'jquery', 'underscore', 'backbone'], function(environ, $, _, Backbone) {
  var Container;
  Container = (function(_super) {

    __extends(Container, _super);

    function Container() {
      return Container.__super__.constructor.apply(this, arguments);
    }

    Container.prototype.template = _.template('\
            <div class=area-container>\
                <h3 class=heading></h3>\
                <div class=content></div>\
            </div>\
        ');

    Container.prototype.initialize = function() {
      this.setElement(this.template());
      this.heading = this.$el.find('.heading');
      return this.content = this.$el.find('.content');
    };

    Container.prototype.render = function() {
      return this.$el;
    };

    return Container;

  })(Backbone.View);
  return {
    Container: Container
  };
});
