var __hasProp={}.hasOwnProperty,__extends=function(e,t){function r(){this.constructor=e}for(var n in t)__hasProp.call(t,n)&&(e[n]=t[n]);return r.prototype=t.prototype,e.prototype=new r,e.__super__=t.prototype,e};define(["environ","jquery","underscore","backbone"],function(e,t,n,r){var i;return i=function(e){function t(){return t.__super__.constructor.apply(this,arguments)}return __extends(t,e),t.prototype.id="composite-area",t.prototype.load=function(){return this.$el.fadeIn()},t.prototype.unload=function(){return this.$el.hide()},t}(r.View)})