// Generated by CoffeeScript 1.3.3
var __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

define(['environ', 'mediator', 'jquery', 'underscore', 'backbone', 'views/counter'], function(environ, mediator, $, _, Backbone, DataContextCount) {
  var AppArea;
  return AppArea = (function(_super) {

    __extends(AppArea, _super);

    function AppArea() {
      return AppArea.__super__.constructor.apply(this, arguments);
    }

    AppArea.prototype.load = function() {
      var view;
      view = new DataContextCount;
      this.$toolbar = $('<ul>').addClass('nav pull-left').appendTo('#subnav .container-fluid');
      return this.$toolbar.append($('<li>').html(view.render()));
    };

    return AppArea;

  })(Backbone.View);
});
