{% extends "cilantro/base.html" %}
{% load url from future %}

{% block scripts %}
    <script data-main=main src="{{ cilantro.javascript_url }}/require.js"></script>
{% endblock scripts %}

{% block content %}
    <div class=container-fluid>
        <div class=row-fluid>
            <div id=main-area class=scrollable-column>
                <div class=inner></div>
            </div>
        </div>
    </div>
{% endblock content %}
