// Generated by CoffeeScript 1.3.3

define(['jquery', 'plugins/bootstrap'], function($) {
  return $('body').tooltip({
    title: 'This is unpublished content and viewable only by staff',
    selector: '.staff-only',
    placement: function() {
      return this.$element.attr('data-placement') || 'top';
    }
  });
});
