{% load url from future %}<!doctype html>
<!--[if lt IE 7]>      <html class="no-js lt-ie9 lt-ie8 lt-ie7"> <![endif]-->
<!--[if IE 7]>         <html class="no-js lt-ie9 lt-ie8"> <![endif]-->
<!--[if IE 8]>         <html class="no-js lt-ie9"> <![endif]-->
<!--[if gt IE 8]><!--> <html class="no-js"> <!--<![endif]-->
    <head>
        <meta charset="utf-8">
        <meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">

        <title>{% block head_title %}{{ cilantro.config.title }}{% endblock %}</title>
        <meta name="description" content="{{ cilantro.config.subtitle }}">

        <!-- Mobile viewport optimized: h5bp.com/viewport -->
        <meta name="viewport" content="width=device-width">

        <!-- Place favicon.ico and apple-touch-icon.png in the root directory -->

        {% block styles %}
            <link rel=stylesheet href="{{ cilantro.css_url }}/style.css">
        {% endblock %}
        <script src="{{ cilantro.javascript_url }}/modernizr.js"></script>
    </head>
    <body>
        <!--[if lt IE 9]><p class="chromeframe">You are using an outdated browser. <a href="http://browsehappy.com/">Upgrade your browser today</a> or <a href="http://www.google.com/chromeframe/?redirect=true">install Google Chrome Frame</a> to better experience this site.</p><![endif]-->

        {% block header %}
            {% include "cilantro/header.html" %}
        {% endblock %}

        {% block subnav %}
            {% include "cilantro/subnav.html" %}
        {% endblock %}

        {% block content %}
            {% include "cilantro/content.html" %}
        {% endblock %}

        {% block footer %}
            {% include "cilantro/footer.html" %}
        {% endblock %}

        {% block extra_content %}{% endblock %}

        <script>{% include "cilantro/config.js" %}</script>

        {% block scripts %}
            <script data-main=environ src="{{ cilantro.javascript_url }}/require.js"></script>
        {% endblock scripts %}

        <!-- Google Analytics: Change UA-XXXXX-X to be your site's ID. -->
        {% if cilantro.config.google_analytics %}
        <script>
            var _gaq=[['_setAccount','{{ cilantro.config.google_analytics }}'],['_trackPageview']];
            (function(d,t){var g=d.createElement(t),s=d.getElementsByTagName(t)[0];
            g.src=('https:'==location.protocol?'//ssl':'//www')+'.google-analytics.com/ga.js';
            s.parentNode.insertBefore(g,s)}(document,'script'));
        </script>
        {% endif %}
    </body>
</html>
