// Generated by CoffeeScript 1.3.3
var __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

define(['environ', 'serrano'], function(environ, Serrano) {
  var DataFields;
  DataFields = (function(_super) {

    __extends(DataFields, _super);

    function DataFields() {
      return DataFields.__super__.constructor.apply(this, arguments);
    }

    DataFields.prototype.url = App.urls.datafields;

    DataFields.prototype.initialize = function() {
      DataFields.__super__.initialize.apply(this, arguments);
      this.on('reset', this.resolve);
      return this.fetch();
    };

    return DataFields;

  })(Serrano.DataFields);
  return App.DataField = new DataFields;
});
